#!/bin/sh

version=$2
orig_tgz=$(basename $3)
orig_txz=requirejs_${version}.orig.tar.xz
newdir=$(echo $orig_tgz | sed -e 's/.orig.tar.gz//' -e 's/_/-/')


wd=$(pwd)

cd ..

tar xzf $orig_tgz && mv r.js-${version} ${newdir}


if [ -L $orig_tgz ] ; then rm $(readlink $orig_tgz); fi
rm $orig_tgz

tar cJf $orig_txz $newdir

echo "Created ../$orig_txz and ../$newdir"
